@@ -19,8 +19,7 @@ use binread::BinRead;
 /// Compatible with file version 1.8 and 1.10.
 #[cfg_attr(feature = "derive_serde", derive(Serialize, Deserialize))]
 #[derive(BinRead, Debug, SsbhWrite)]
-#[align_after(8)]
-#[padding(16)]
+#[ssbhwrite(pad_after = 16, align_after = 8)]
 pub struct Mesh {
     pub major_version: u16,
     pub minor_version: u16,
@@ -100,7 +99,7 @@ pub struct MeshAttributeV8 {
 
 #[cfg_attr(feature = "derive_serde", derive(Serialize, Deserialize))]
 #[derive(BinRead, Debug, SsbhWrite, Copy, Clone)]
-#[padding(6)]
+#[ssbhwrite(pad_after = 6)]
 pub struct RiggingFlags {
     pub max_influences: u8,
     #[br(pad_after = 6)]
@@ -117,7 +116,7 @@ pub struct MeshBoneBuffer {
 }
 
 #[cfg_attr(feature = "derive_serde", derive(Serialize, Deserialize))]
-#[derive(BinRead, Debug, SsbhWrite)]
+#[derive(BinRead, Debug)]
 #[br(import(major_version: u16, minor_version: u16))]
 pub enum VertexWeights {
     #[br(pre_assert(major_version == 1 &&  minor_version == 8))]
@@ -127,7 +126,8 @@ pub enum VertexWeights {
     VertexWeightsV10(SsbhByteBuffer),
 }
 
-/// Vertex skinning data for the vertices for the [MeshObject] determined by []
+/// Vertex skinning data for the vertices for the [MeshObject] 
+/// determined by [mesh_object_name](#structfield.mesh_object_name) and [mesh_object_sub_index](#structfield.mesh_object_sub_index).
 #[cfg_attr(feature = "derive_serde", derive(Serialize, Deserialize))]
 #[derive(BinRead, Debug, SsbhWrite)]
 #[br(import(major_version: u16, minor_version: u16))]
@@ -140,7 +140,7 @@ pub struct MeshRiggingGroup {
 }
 
 #[cfg_attr(feature = "derive_serde", derive(Serialize, Deserialize))]
-#[derive(BinRead, Debug, SsbhWrite)]
+#[derive(BinRead, Debug)]
 #[br(import(major_version: u16, minor_version: u16))]
 pub enum MeshAttributes {
     #[br(pre_assert(major_version == 1 &&  minor_version == 8))]
@@ -212,7 +212,7 @@ pub struct MeshObject {
 
 /// Possible values for [draw_element_type](struct.MeshObject.html#structfield.draw_element_type).
 #[cfg_attr(feature = "derive_serde", derive(Serialize, Deserialize))]
-#[derive(BinRead, Debug, Clone, Copy)]
+#[derive(BinRead, Debug, Clone, Copy, PartialEq)]
 #[br(repr(u32))]
 pub enum DrawElementType {
     /// Vertex indices stored as [u16].
@@ -223,7 +223,7 @@ pub enum DrawElementType {
 
 /// Possible values for [rigging_type](struct.MeshObject.html#structfield.rigging_type).
 #[cfg_attr(feature = "derive_serde", derive(Serialize, Deserialize))]
-#[derive(BinRead, Debug, Clone, Copy)]
+#[derive(BinRead, Debug, Clone, Copy, PartialEq)]
 #[br(repr(u32))]
 pub enum RiggingType {
     /// Vertices are parented to a parent bone and inherit the parent's transforms.
@@ -236,7 +236,7 @@ pub enum RiggingType {
 /// The data type and component count for the attribute's data.
 /// This determines the stride and offset between attributes.
 #[cfg_attr(feature = "derive_serde", derive(Serialize, Deserialize))]
-#[derive(BinRead, Debug, Clone, Copy)]
+#[derive(BinRead, Debug, Clone, Copy, PartialEq)]
 #[br(repr(u32))]
 pub enum AttributeDataType {
     /// 3 component (xyz or rgb) vector of [f32].
@@ -256,7 +256,7 @@ pub enum AttributeDataType {
 /// The data type and component count for the attribute's data.
 /// This determines the stride and offset between attributes.
 #[cfg_attr(feature = "derive_serde", derive(Serialize, Deserialize))]
-#[derive(BinRead, Debug, Clone, Copy)]
+#[derive(BinRead, Debug, Clone, Copy, PartialEq)]
 #[br(repr(u32))]
 pub enum AttributeDataTypeV8 {
     /// 3 component (xyz or rgb) vector of [f32].
